# CPDAG Estimation using PC-Algorithm

## Overview

This package provides functions to estimate a skeleton graph and a
completed partially acyclic graph (CPDAG)from a data matrix that
describes the appearance patterns of the graph nodes.  The detailed
algorithm is written in [Kalisch2007].

## References

[Kalisch2007] Markus Kalisch and Peter Bhlmann. Estimating
high-dimensional directed acyclic graphs with the pc-algorithm. In The
Journal of Machine Learning Research, Vol. 8, pp. 613-636, 2007.
